# Copyright 2021 AI Redefined Inc. <dev+cogment@ai-r.com>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from posixpath import join
import grpc
import grpc.aio  # type: ignore
from prometheus_client import start_http_server as start_prometheus_server
from prometheus_client.core import REGISTRY  # type: ignore

import cogment.api.orchestrator_pb2_grpc as orchestrator_grpc_api
import cogment.api.agent_pb2_grpc as agent_grpc_api
import cogment.api.environment_pb2_grpc as env_grpc_api
import cogment.api.hooks_pb2_grpc as hooks_grpc_api
import cogment.api.datalog_pb2_grpc as datalog_grpc_api
import cogment.api.trial_datastore_pb2_grpc as datastore_grpc_api

from cogment.actor import ActorSession
from cogment.environment import EnvironmentSession
from cogment.prehook import PrehookSession
from cogment.datalog import DatalogSession
from cogment.datastore import Datastore
from cogment.control import Controller
from cogment.errors import CogmentError
from cogment.agent_service import AgentServicer, get_actor_impl
from cogment.client_service import ClientServicer
from cogment.env_service import EnvironmentServicer
from cogment.hooks_service import PrehookServicer
from cogment.datalog_service import DatalogServicer
from cogment.utils import logger

from typing import Callable, Awaitable, Dict, List, Any
from types import ModuleType
import os
import asyncio
from types import SimpleNamespace


DEFAULT_PROMETHEUS_PORT = 8000


class Endpoint:
    """Class representing a remote Cogment endpoint where to connect."""

    def __init__(self, url: str):
        self.url = url
        self.private_key = None
        self.root_certificates = None
        self.certificate_chain = None

    def __str__(self):
        result = f"Endpoint: url = {self.url}, private_key = {self.private_key}"
        result += f", root_certificates = {self.root_certificates}, certificate_chain = {self.certificate_chain}"
        return result

    def set_from_files(self, private_key_file=None, root_certificates_file=None, certificate_chain_file=None):
        try:
            if private_key_file:
                with open(private_key_file) as fl:
                    self.private_key = fl.read()
                if not self.private_key:
                    self.private_key = None

            if root_certificates_file:
                with open(root_certificates_file) as fl:
                    self.root_certificates = fl.read()
                if not self.root_certificates:
                    self.root_certificates = None

            if certificate_chain_file:
                with open(certificate_chain_file) as fl:
                    self.certificate_chain = fl.read()
                if not self.certificate_chain:
                    self.certificate_chain = None

        except Exception:
            logger.error(f"Failed loading file from CWD: {os.getcwd()}")
            raise


class ServedEndpoint:
    """Class representing a local Cogment endpoint where others can connect."""

    def __init__(self, port: int):
        self.port = port
        self.private_key_certificate_chain_pairs = None
        self.root_certificates = None

    # def set_from_files(private_key_certificate_chain_pairs_file=None, root_certificates_file=None):
    # TODO: This function would need to parse the PEM encoded `private_key_certificate_chain_pairs_file`
    #       to create the list of tuples required (see simpler version in `Endpoint` class above).

    def __str__(self):
        result = f"ServedEndpoint: port = {self.port}"
        result += f", private_key_certificate_chain_pairs = {self.private_key_certificate_chain_pairs}"
        result += f", root_certificates = {self.root_certificates}"
        return result


def _make_client_channel(endpoint: Endpoint):
    if endpoint.url[:7] == "grpc://":
        url = endpoint.url[7:]
    else:
        logger.warning(f"Endpoint URL must be of gRPC type (start with 'grpc://') [{endpoint.url}]")
        url = endpoint.url

    if endpoint.private_key is None:
        channel = grpc.aio.insecure_channel(url)
    else:
        if endpoint.root_certificates:
            root = bytes(endpoint.root_certificates, "utf-8")
        else:
            root = None
        if endpoint.private_key:
            key = bytes(endpoint.private_key, "utf-8")
        else:
            key = None
        if endpoint.certificate_chain:
            certs = bytes(endpoint.certificate_chain, "utf-8")
        else:
            certs = None
        creds = grpc.ssl_channel_credentials(root, key, certs)
        channel = grpc.aio.secure_channel(url, creds)

    return channel


def _make_server(endpoint: ServedEndpoint):
    server = grpc.aio.server()

    address = f"[::]:{endpoint.port}"
    if endpoint.private_key_certificate_chain_pairs is None:
        server.add_insecure_port(address)
    else:
        if endpoint.root_certificates:
            require_client_auth = True
            root = bytes(endpoint.root_certificates, "utf-8")
        else:
            require_client_auth = False
            root = None
        certs = []
        for (key, chain) in endpoint.private_key_certificate_chain_pairs:
            certs.append((bytes(key, "utf-8"), bytes(chain, "utf-8")))
        if not certs:
            certs = None

        creds = grpc.ssl_server_credentials(certs, root, require_client_auth)
        server.add_secure_port(address, creds)

    return server


class Context:
    """Top level class for the Cogment library from which to obtain all services."""

    def __init__(self, user_id: str, cog_settings: ModuleType, asyncio_loop=None, prometheus_registry=REGISTRY):
        self._user_id = user_id
        self._actor_impls: Dict[str, SimpleNamespace] = {}
        self._env_impls: Dict[str, SimpleNamespace] = {}
        self._prehook_impl: Callable[[PrehookSession], Awaitable[None]] = None
        self._datalog_impl: Callable[[DatalogSession], Awaitable[None]] = None
        self._grpc_server = None  # type: Any
        self._prometheus_registry = prometheus_registry
        self._cog_settings = cog_settings

        if asyncio_loop is None:
            # Make sure we are running in a asyncio.Task. Even if technically this init does not need
            # to be in a Task, the whole of the SDK expects to be running in Tasks of the same event loop.
            try:
                self.asyncio_loop = asyncio.get_running_loop()
            except RuntimeError:
                raise CogmentError("The Cogment SDK requires running in a Python `asyncio` Task")
        else:
            self.asyncio_loop = asyncio_loop

    def __str__(self):
        result = f"Cogment Context: user id = {self._user_id}"
        return result

    def register_actor(self,
                       impl: Callable[[ActorSession], Awaitable[None]],
                       impl_name: str,
                       actor_classes: List[str] = []):
        if self._grpc_server is not None:
            # We could accept "client" actor registration after the server is started, but it is not worth it
            raise CogmentError("Cannot register an actor after the server is started")
        if impl_name in self._actor_impls:
            raise CogmentError(f"The actor implementation name must be unique: [{impl_name}]")

        self._actor_impls[impl_name] = SimpleNamespace(impl=impl, actor_classes=actor_classes)

    def register_environment(self,
                             impl: Callable[[EnvironmentSession], Awaitable[None]],
                             impl_name: str = "default"):
        if self._grpc_server is not None:
            raise CogmentError("Cannot register an environment after the server is started")
        if impl_name in self._env_impls:
            raise CogmentError(f"The environment implementation name must be unique: [{impl_name}]")

        self._env_impls[impl_name] = SimpleNamespace(impl=impl)

    def register_pre_trial_hook(self,
                                impl: Callable[[PrehookSession], Awaitable[None]]):
        if self._grpc_server is not None:
            raise CogmentError("Cannot register a pre-trial hook after the server is started")
        if self._prehook_impl is not None:
            raise CogmentError("Only one pre-trial hook service can be registered")

        self._prehook_impl = impl

    def register_datalog(self,
                         impl: Callable[[DatalogSession], Awaitable[None]]):
        if self._grpc_server is not None:
            raise CogmentError("Cannot register a datalog after the server is started")
        if self._datalog_impl is not None:
            raise CogmentError("Only one datalog service can be registered")

        self._datalog_impl = impl

    async def serve_all_registered(self, served_endpoint: ServedEndpoint, prometheus_port=DEFAULT_PROMETHEUS_PORT):
        if (len(self._actor_impls) == 0 and len(self._env_impls) == 0 and
                self._prehook_impl is None and self._datalog_impl is None):
            raise CogmentError("Nothing registered to serve!")
        if self._grpc_server is not None:
            raise CogmentError("Cannot serve the same components twice")

        self._grpc_server = _make_server(served_endpoint)

        if self._actor_impls:
            servicer = AgentServicer(self._actor_impls, self._cog_settings, self._prometheus_registry)
            agent_grpc_api.add_ServiceActorSPServicer_to_server(servicer, self._grpc_server)

        if self._env_impls:
            servicer = EnvironmentServicer(self._env_impls, self._cog_settings, self._prometheus_registry)
            env_grpc_api.add_EnvironmentSPServicer_to_server(servicer, self._grpc_server)

        if self._prehook_impl is not None:
            servicer = PrehookServicer(self._prehook_impl, self._cog_settings, self._prometheus_registry)
            hooks_grpc_api.add_TrialHooksSPServicer_to_server(servicer, self._grpc_server)

        if self._datalog_impl is not None:
            servicer = DatalogServicer(self._datalog_impl, self._cog_settings)
            datalog_grpc_api.add_DatalogSPServicer_to_server(servicer, self._grpc_server)

        if self._prometheus_registry is not None and prometheus_port is not None:
            start_prometheus_server(prometheus_port, "", self._prometheus_registry)

        await self._grpc_server.start()
        logger.debug(f"Context gRPC server at port [{served_endpoint.port}] for user [{self._user_id}] started")
        await self._grpc_server.wait_for_termination()
        logger.debug(f"Context gRPC server at port [{served_endpoint.port}] for user [{self._user_id}] exited")

    def get_controller(self, endpoint: Endpoint):
        channel = _make_client_channel(endpoint)
        stub = orchestrator_grpc_api.TrialLifecycleSPStub(channel)
        return Controller(stub, self._user_id)

    def get_datastore(self, endpoint: Endpoint):
        channel = _make_client_channel(endpoint)
        stub = datastore_grpc_api.TrialDatastoreSPStub(channel)
        return Datastore(stub, self._cog_settings)

    async def join_trial(self, trial_id, endpoint: Endpoint, impl_name=None, actor_name=None, actor_class=None):
        requested_class = None
        requested_name = None
        if impl_name is not None:
            # For backward compatibility
            logger.warning(f"`join_trial` parameter `impl_name` is deprecated")
            if actor_name is None:
                actor_impl = self._actor_impls[impl_name]
                if len(actor_impl.actor_classes) == 0:
                    raise CogmentError(f"Unable to determine possible actor to join trial: "
                                       f"impl_name [{impl_name}] does not have any registered actor class")
                requested_class = actor_impl.actor_classes[0]
            else:
                requested_name = actor_name

        elif actor_name is not None:
            requested_name = actor_name
            if actor_class is not None:
                logger.warning(f"`actor_class` will be ignored because `actor_name` is provided in `join_trial")

        elif actor_class is not None:
            requested_class = actor_class

        else:
            raise CogmentError(f"Actor name or actor class must be specified to join a trial")

        channel = _make_client_channel(endpoint)
        stub = orchestrator_grpc_api.ClientActorSPStub(channel)
        servicer = ClientServicer(self._cog_settings, stub)

        init_data = await servicer.join_trial(trial_id, requested_name, requested_class)
        if not init_data:
            return

        if requested_name is not None and requested_name != init_data.actor_name:
            raise CogmentError(f"Internal failure: Actor name [{requested_name}] requested, received: {init_data}")
        if requested_class is not None and requested_class != init_data.actor_class:
            raise CogmentError(f"Internal failure: Actor class [{requested_class}] requested, received: {init_data}")

        if impl_name is not None and init_data.impl_name and init_data.impl_name != impl_name:
            logger.warning(f"Requested impl_name [{impl_name}] does not match trial impl_name "
                           f"[{init_data.impl_name}]: Requested impl_name will be used.")
            init_data.impl_name = impl_name

        actor_impl = get_actor_impl(trial_id, self._actor_impls, init_data)

        await servicer.run_session(actor_impl.impl, init_data)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['cogment', 'cogment.api']

package_data = \
{'': ['*']}

install_requires = \
['grpcio-reflection>=1.42,<1.45',
 'grpcio>=1.42,<1.45',
 'prometheus-client>=0.8,<0.9',
 'protobuf>=3.7,<4.0']

extras_require = \
{'generate': ['PyYAML>=5.3.1,<6.0.0',
              'grpcio-tools==1.43',
              'click>=8.0.3,<9.0.0']}

setup_kwargs = {
    'name': 'cogment',
    'version': '2.2.0',
    'description': 'Cogment python SDK',
    'long_description': '# cogment-py-sdk\n\n[![Latest final release](https://img.shields.io/pypi/v/cogment?style=flat-square)](https://pypi.org/project/cogment/) [![Apache 2 License](https://img.shields.io/badge/license-Apache%202-green?style=flat-square)](./LICENSE) [![Changelog](https://img.shields.io/badge/-Changelog%20-blueviolet?style=flat-square)](./CHANGELOG.md)\n\n[Cogment](https://cogment.ai) is an innovative open source AI platform designed to leverage the advent of AI to benefit humankind through human-AI collaboration developed by [AI Redefined](https://ai-r.com). Cogment enables AI researchers and engineers to build, train and operate AI agents in simulated or real environments shared with humans. For the full user documentation visit <https://docs.cogment.ai>\n\nThis module, `cogment-py-sdk`, is the Python SDK for making use of Cogment when working with Python. It\'s full documentation can be consulted at <https://docs.cogment.ai/cogment/cogment-api-reference/python/>.\n\n## Developers\n\n### Local setup\n\nMake sure you have the following installed:\n\n- [Python](https://www.python.org) (any version >=3.7 should work),\n- [Poetry](https://python-poetry.org).\n\nInstall the dependencies, including downloading and building the cogment protobuf API, by navigating to the python SDK directory and run the following\n\n```\npoetry install\n```\n\n### Define used Cogment protobuf API\n\nThe version of the used cogment protobuf API is defined in the `.cogment-api.yaml` file at the root of the repository. The following can be defined:\n\n- `cogment_version: "latest"`, is the default, it retrieves the api from the _latest_ Cogment release (excluding pre-releases),\n- `cogment_version: "vMAJOR.MINOR.PATCH[-PRERELEASE]"`, retrieves the api from any Cogment release.\n- `cogment_api_path: "../RELATIVE/PATH/TO/LOCAL/COGMENT/INSTALL/include/cogment/api"`, retrieves a local version of the api found at the given path (e.g. `common.proto` should be at `${cogment_api_path}/common.proto`); if set, this overrides `cogment_version`.\n\n### Tests\n\n#### Integration tests\n\nThese tests launch and use Cogment, by default they\'ll use they\'ll download and use the latest released version of Cogment.\n\n```console\npoetry run task test --launch-orchestrator\n```\n\nThe following environment can be defined to change this behavior, either directly in the terminal or in a `.env` file located at the root of the repository:\n\n```bash\nCOGMENT_PATH="/path/to/cogment" # local path to cogment binary\nCOGMENT_VERSION="v2.2.0" # cogment version to download\n```\n\n### Lint\n\nRun the linter using\n\n```console\npoetry run task lint\n```\n\n### Check conflicting dependencies with "popular" Python packages\n\n```console\n./scripts/check_dependencies_conflicts.sh\n```\n\nThis script will check for conflicts required by the cogment-py-sdk and the popular Python packages in the AI/ML/Data ecosystem.\n\n### Build the source package\n\nBuild the source package (this step will only be succesfull if `poetry install` succeeded)\n\n```console\npoetry build -f sdist\n```\n\n### Release process\n\nPeople having mainteners rights of the repository can follow these steps to release a version **MAJOR.MINOR.PATCH**. The versioning scheme follows [Semantic Versioning](http://semver.org/spec/v2.0.0.html).\n\n1. Run `./scripts/create_release_branch.sh MAJOR.MINOR.PATCH` to create the release branch and update the version of the package,\n2. On the release branch, check and update the changelog if needed,\n3. Make sure `./.cogment-api.yaml` specifies fixed version to ensure rebuildability,\n4. Make sure everything\'s fine on CI,\n5. Run `./scripts/tag_release.sh MAJOR.MINOR.PATCH` to create the specific version section in the changelog, merge the release branch in `main`, create the release tag and update the `develop` branch with those.\n\nThe rest, publishing the package to PyPI and updating the mirror repositories, is handled directly by the CI.\n',
    'author': 'Artificial Intelligence Redefined',
    'author_email': 'dev+cogment@ai-r.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://cogment.ai',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.7,<3.10',
}
from build import *
build(setup_kwargs)

setup(**setup_kwargs)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/datalog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogment.api import common_pb2 as cogment_dot_api_dot_common__pb2
from cogment.api import environment_pb2 as cogment_dot_api_dot_environment__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogment/api/datalog.proto',
  package='cogmentAPI',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19\x63ogment/api/datalog.proto\x12\ncogmentAPI\x1a\x18\x63ogment/api/common.proto\x1a\x1d\x63ogment/api/environment.proto\x1a\x19google/protobuf/any.proto\"{\n\x14RunTrialDatalogInput\x12/\n\x0ctrial_params\x18\x01 \x01(\x0b\x32\x17.cogmentAPI.TrialParamsH\x00\x12+\n\x06sample\x18\x02 \x01(\x0b\x32\x19.cogmentAPI.DatalogSampleH\x00\x42\x05\n\x03msg\"\x17\n\x15RunTrialDatalogOutput\"o\n\nSampleInfo\x12\x0f\n\x07tick_id\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x06\x12%\n\x05state\x18\x03 \x01(\x0e\x32\x16.cogmentAPI.TrialState\x12\x16\n\x0especial_events\x18\x04 \x03(\t\"\xd8\x01\n\rDatalogSample\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.cogmentAPI.SampleInfo\x12\x30\n\x0cobservations\x18\x02 \x01(\x0b\x32\x1a.cogmentAPI.ObservationSet\x12#\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32\x12.cogmentAPI.Action\x12#\n\x07rewards\x18\x04 \x03(\x0b\x32\x12.cogmentAPI.Reward\x12%\n\x08messages\x18\x05 \x03(\x0b\x32\x13.cogmentAPI.Message\"!\n\x0eTrialConfig_v1\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"!\n\x0e\x41\x63torConfig_v1\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"\'\n\x14\x45nvironmentConfig_v1\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"r\n\x14\x45nvironmentParams_v1\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x30\n\x06\x63onfig\x18\x02 \x01(\x0b\x32 .cogmentAPI.EnvironmentConfig_v1\x12\x16\n\x0eimplementation\x18\x03 \x01(\t\"\x89\x01\n\x0e\x41\x63torParams_v1\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63tor_class\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\t\x12\x16\n\x0eimplementation\x18\x04 \x01(\t\x12*\n\x06\x63onfig\x18\x05 \x01(\x0b\x32\x1a.cogmentAPI.ActorConfig_v1\"\xd0\x01\n\x0eTrialParams_v1\x12\x30\n\x0ctrial_config\x18\x01 \x01(\x0b\x32\x1a.cogmentAPI.TrialConfig_v1\x12\x35\n\x0b\x65nvironment\x18\x02 \x01(\x0b\x32 .cogmentAPI.EnvironmentParams_v1\x12*\n\x06\x61\x63tors\x18\x03 \x03(\x0b\x32\x1a.cogmentAPI.ActorParams_v1\x12\x11\n\tmax_steps\x18\x04 \x01(\r\x12\x16\n\x0emax_inactivity\x18\x05 \x01(\r\"7\n\x12ObservationData_v1\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x10\n\x08snapshot\x18\x02 \x01(\x08\"\x81\x01\n\x11ObservationSet_v1\x12\x0f\n\x07tick_id\x18\x01 \x01(\x12\x12\x11\n\ttimestamp\x18\x02 \x01(\x06\x12\x34\n\x0cobservations\x18\x03 \x03(\x0b\x32\x1e.cogmentAPI.ObservationData_v1\x12\x12\n\nactors_map\x18\x04 \x03(\x05\"-\n\tAction_v1\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x0f\n\x07tick_id\x18\x02 \x01(\x12\"r\n\x0fRewardSource_v1\x12\x13\n\x0bsender_name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\x12\x12\n\nconfidence\x18\x03 \x01(\x02\x12\'\n\tuser_data\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"p\n\tReward_v1\x12\x15\n\rreceiver_name\x18\x01 \x01(\t\x12\x0f\n\x07tick_id\x18\x02 \x01(\x12\x12\r\n\x05value\x18\x03 \x01(\x02\x12,\n\x07sources\x18\x04 \x03(\x0b\x32\x1b.cogmentAPI.RewardSource_v1\"p\n\nMessage_v1\x12\x0f\n\x07tick_id\x18\x01 \x01(\x12\x12\x13\n\x0bsender_name\x18\x02 \x01(\t\x12\x15\n\rreceiver_name\x18\x03 \x01(\t\x12%\n\x07payload\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"\x80\x02\n\x10\x44\x61talogSample_v1\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x33\n\x0cobservations\x18\x02 \x01(\x0b\x32\x1d.cogmentAPI.ObservationSet_v1\x12&\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32\x15.cogmentAPI.Action_v1\x12&\n\x07rewards\x18\x04 \x03(\x0b\x32\x15.cogmentAPI.Reward_v1\x12(\n\x08messages\x18\x05 \x03(\x0b\x32\x16.cogmentAPI.Message_v1\x12,\n\ntrial_data\x18\x06 \x01(\x0b\x32\x18.cogmentAPI.TrialData_v1\"Y\n\x0cTrialData_v1\x12\x0f\n\x07tick_id\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x06\x12%\n\x05state\x18\x03 \x01(\x0e\x32\x16.cogmentAPI.TrialState2\xab\x01\n\tDatalogSP\x12\\\n\x0fRunTrialDatalog\x12 .cogmentAPI.RunTrialDatalogInput\x1a!.cogmentAPI.RunTrialDatalogOutput\"\x00(\x01\x30\x01\x12@\n\x07Version\x12\x1a.cogmentAPI.VersionRequest\x1a\x17.cogmentAPI.VersionInfo\"\x00\x62\x06proto3'
  ,
  dependencies=[cogment_dot_api_dot_common__pb2.DESCRIPTOR,cogment_dot_api_dot_environment__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])




_RUNTRIALDATALOGINPUT = _descriptor.Descriptor(
  name='RunTrialDatalogInput',
  full_name='cogmentAPI.RunTrialDatalogInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_params', full_name='cogmentAPI.RunTrialDatalogInput.trial_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample', full_name='cogmentAPI.RunTrialDatalogInput.sample', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='msg', full_name='cogmentAPI.RunTrialDatalogInput.msg',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=125,
  serialized_end=248,
)


_RUNTRIALDATALOGOUTPUT = _descriptor.Descriptor(
  name='RunTrialDatalogOutput',
  full_name='cogmentAPI.RunTrialDatalogOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=273,
)


_SAMPLEINFO = _descriptor.Descriptor(
  name='SampleInfo',
  full_name='cogmentAPI.SampleInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.SampleInfo.tick_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='cogmentAPI.SampleInfo.timestamp', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='cogmentAPI.SampleInfo.state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='special_events', full_name='cogmentAPI.SampleInfo.special_events', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=386,
)


_DATALOGSAMPLE = _descriptor.Descriptor(
  name='DatalogSample',
  full_name='cogmentAPI.DatalogSample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='cogmentAPI.DatalogSample.info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observations', full_name='cogmentAPI.DatalogSample.observations', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actions', full_name='cogmentAPI.DatalogSample.actions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rewards', full_name='cogmentAPI.DatalogSample.rewards', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='cogmentAPI.DatalogSample.messages', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=605,
)


_TRIALCONFIG_V1 = _descriptor.Descriptor(
  name='TrialConfig_v1',
  full_name='cogmentAPI.TrialConfig_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogmentAPI.TrialConfig_v1.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=607,
  serialized_end=640,
)


_ACTORCONFIG_V1 = _descriptor.Descriptor(
  name='ActorConfig_v1',
  full_name='cogmentAPI.ActorConfig_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogmentAPI.ActorConfig_v1.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=642,
  serialized_end=675,
)


_ENVIRONMENTCONFIG_V1 = _descriptor.Descriptor(
  name='EnvironmentConfig_v1',
  full_name='cogmentAPI.EnvironmentConfig_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogmentAPI.EnvironmentConfig_v1.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=677,
  serialized_end=716,
)


_ENVIRONMENTPARAMS_V1 = _descriptor.Descriptor(
  name='EnvironmentParams_v1',
  full_name='cogmentAPI.EnvironmentParams_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='cogmentAPI.EnvironmentParams_v1.endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='cogmentAPI.EnvironmentParams_v1.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='implementation', full_name='cogmentAPI.EnvironmentParams_v1.implementation', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=718,
  serialized_end=832,
)


_ACTORPARAMS_V1 = _descriptor.Descriptor(
  name='ActorParams_v1',
  full_name='cogmentAPI.ActorParams_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='cogmentAPI.ActorParams_v1.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_class', full_name='cogmentAPI.ActorParams_v1.actor_class', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='cogmentAPI.ActorParams_v1.endpoint', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='implementation', full_name='cogmentAPI.ActorParams_v1.implementation', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='cogmentAPI.ActorParams_v1.config', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=835,
  serialized_end=972,
)


_TRIALPARAMS_V1 = _descriptor.Descriptor(
  name='TrialParams_v1',
  full_name='cogmentAPI.TrialParams_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_config', full_name='cogmentAPI.TrialParams_v1.trial_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='cogmentAPI.TrialParams_v1.environment', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actors', full_name='cogmentAPI.TrialParams_v1.actors', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_steps', full_name='cogmentAPI.TrialParams_v1.max_steps', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_inactivity', full_name='cogmentAPI.TrialParams_v1.max_inactivity', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=975,
  serialized_end=1183,
)


_OBSERVATIONDATA_V1 = _descriptor.Descriptor(
  name='ObservationData_v1',
  full_name='cogmentAPI.ObservationData_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogmentAPI.ObservationData_v1.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot', full_name='cogmentAPI.ObservationData_v1.snapshot', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1185,
  serialized_end=1240,
)


_OBSERVATIONSET_V1 = _descriptor.Descriptor(
  name='ObservationSet_v1',
  full_name='cogmentAPI.ObservationSet_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.ObservationSet_v1.tick_id', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='cogmentAPI.ObservationSet_v1.timestamp', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observations', full_name='cogmentAPI.ObservationSet_v1.observations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actors_map', full_name='cogmentAPI.ObservationSet_v1.actors_map', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1243,
  serialized_end=1372,
)


_ACTION_V1 = _descriptor.Descriptor(
  name='Action_v1',
  full_name='cogmentAPI.Action_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogmentAPI.Action_v1.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.Action_v1.tick_id', index=1,
      number=2, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1374,
  serialized_end=1419,
)


_REWARDSOURCE_V1 = _descriptor.Descriptor(
  name='RewardSource_v1',
  full_name='cogmentAPI.RewardSource_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender_name', full_name='cogmentAPI.RewardSource_v1.sender_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='cogmentAPI.RewardSource_v1.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='cogmentAPI.RewardSource_v1.confidence', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_data', full_name='cogmentAPI.RewardSource_v1.user_data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1421,
  serialized_end=1535,
)


_REWARD_V1 = _descriptor.Descriptor(
  name='Reward_v1',
  full_name='cogmentAPI.Reward_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='receiver_name', full_name='cogmentAPI.Reward_v1.receiver_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.Reward_v1.tick_id', index=1,
      number=2, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='cogmentAPI.Reward_v1.value', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sources', full_name='cogmentAPI.Reward_v1.sources', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1537,
  serialized_end=1649,
)


_MESSAGE_V1 = _descriptor.Descriptor(
  name='Message_v1',
  full_name='cogmentAPI.Message_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.Message_v1.tick_id', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender_name', full_name='cogmentAPI.Message_v1.sender_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiver_name', full_name='cogmentAPI.Message_v1.receiver_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='cogmentAPI.Message_v1.payload', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1651,
  serialized_end=1763,
)


_DATALOGSAMPLE_V1 = _descriptor.Descriptor(
  name='DatalogSample_v1',
  full_name='cogmentAPI.DatalogSample_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='cogmentAPI.DatalogSample_v1.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observations', full_name='cogmentAPI.DatalogSample_v1.observations', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actions', full_name='cogmentAPI.DatalogSample_v1.actions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rewards', full_name='cogmentAPI.DatalogSample_v1.rewards', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='cogmentAPI.DatalogSample_v1.messages', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trial_data', full_name='cogmentAPI.DatalogSample_v1.trial_data', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1766,
  serialized_end=2022,
)


_TRIALDATA_V1 = _descriptor.Descriptor(
  name='TrialData_v1',
  full_name='cogmentAPI.TrialData_v1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.TrialData_v1.tick_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='cogmentAPI.TrialData_v1.timestamp', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='cogmentAPI.TrialData_v1.state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2024,
  serialized_end=2113,
)

_RUNTRIALDATALOGINPUT.fields_by_name['trial_params'].message_type = cogment_dot_api_dot_common__pb2._TRIALPARAMS
_RUNTRIALDATALOGINPUT.fields_by_name['sample'].message_type = _DATALOGSAMPLE
_RUNTRIALDATALOGINPUT.oneofs_by_name['msg'].fields.append(
  _RUNTRIALDATALOGINPUT.fields_by_name['trial_params'])
_RUNTRIALDATALOGINPUT.fields_by_name['trial_params'].containing_oneof = _RUNTRIALDATALOGINPUT.oneofs_by_name['msg']
_RUNTRIALDATALOGINPUT.oneofs_by_name['msg'].fields.append(
  _RUNTRIALDATALOGINPUT.fields_by_name['sample'])
_RUNTRIALDATALOGINPUT.fields_by_name['sample'].containing_oneof = _RUNTRIALDATALOGINPUT.oneofs_by_name['msg']
_SAMPLEINFO.fields_by_name['state'].enum_type = cogment_dot_api_dot_common__pb2._TRIALSTATE
_DATALOGSAMPLE.fields_by_name['info'].message_type = _SAMPLEINFO
_DATALOGSAMPLE.fields_by_name['observations'].message_type = cogment_dot_api_dot_environment__pb2._OBSERVATIONSET
_DATALOGSAMPLE.fields_by_name['actions'].message_type = cogment_dot_api_dot_common__pb2._ACTION
_DATALOGSAMPLE.fields_by_name['rewards'].message_type = cogment_dot_api_dot_common__pb2._REWARD
_DATALOGSAMPLE.fields_by_name['messages'].message_type = cogment_dot_api_dot_common__pb2._MESSAGE
_ENVIRONMENTPARAMS_V1.fields_by_name['config'].message_type = _ENVIRONMENTCONFIG_V1
_ACTORPARAMS_V1.fields_by_name['config'].message_type = _ACTORCONFIG_V1
_TRIALPARAMS_V1.fields_by_name['trial_config'].message_type = _TRIALCONFIG_V1
_TRIALPARAMS_V1.fields_by_name['environment'].message_type = _ENVIRONMENTPARAMS_V1
_TRIALPARAMS_V1.fields_by_name['actors'].message_type = _ACTORPARAMS_V1
_OBSERVATIONSET_V1.fields_by_name['observations'].message_type = _OBSERVATIONDATA_V1
_REWARDSOURCE_V1.fields_by_name['user_data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_REWARD_V1.fields_by_name['sources'].message_type = _REWARDSOURCE_V1
_MESSAGE_V1.fields_by_name['payload'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_DATALOGSAMPLE_V1.fields_by_name['observations'].message_type = _OBSERVATIONSET_V1
_DATALOGSAMPLE_V1.fields_by_name['actions'].message_type = _ACTION_V1
_DATALOGSAMPLE_V1.fields_by_name['rewards'].message_type = _REWARD_V1
_DATALOGSAMPLE_V1.fields_by_name['messages'].message_type = _MESSAGE_V1
_DATALOGSAMPLE_V1.fields_by_name['trial_data'].message_type = _TRIALDATA_V1
_TRIALDATA_V1.fields_by_name['state'].enum_type = cogment_dot_api_dot_common__pb2._TRIALSTATE
DESCRIPTOR.message_types_by_name['RunTrialDatalogInput'] = _RUNTRIALDATALOGINPUT
DESCRIPTOR.message_types_by_name['RunTrialDatalogOutput'] = _RUNTRIALDATALOGOUTPUT
DESCRIPTOR.message_types_by_name['SampleInfo'] = _SAMPLEINFO
DESCRIPTOR.message_types_by_name['DatalogSample'] = _DATALOGSAMPLE
DESCRIPTOR.message_types_by_name['TrialConfig_v1'] = _TRIALCONFIG_V1
DESCRIPTOR.message_types_by_name['ActorConfig_v1'] = _ACTORCONFIG_V1
DESCRIPTOR.message_types_by_name['EnvironmentConfig_v1'] = _ENVIRONMENTCONFIG_V1
DESCRIPTOR.message_types_by_name['EnvironmentParams_v1'] = _ENVIRONMENTPARAMS_V1
DESCRIPTOR.message_types_by_name['ActorParams_v1'] = _ACTORPARAMS_V1
DESCRIPTOR.message_types_by_name['TrialParams_v1'] = _TRIALPARAMS_V1
DESCRIPTOR.message_types_by_name['ObservationData_v1'] = _OBSERVATIONDATA_V1
DESCRIPTOR.message_types_by_name['ObservationSet_v1'] = _OBSERVATIONSET_V1
DESCRIPTOR.message_types_by_name['Action_v1'] = _ACTION_V1
DESCRIPTOR.message_types_by_name['RewardSource_v1'] = _REWARDSOURCE_V1
DESCRIPTOR.message_types_by_name['Reward_v1'] = _REWARD_V1
DESCRIPTOR.message_types_by_name['Message_v1'] = _MESSAGE_V1
DESCRIPTOR.message_types_by_name['DatalogSample_v1'] = _DATALOGSAMPLE_V1
DESCRIPTOR.message_types_by_name['TrialData_v1'] = _TRIALDATA_V1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RunTrialDatalogInput = _reflection.GeneratedProtocolMessageType('RunTrialDatalogInput', (_message.Message,), {
  'DESCRIPTOR' : _RUNTRIALDATALOGINPUT,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.RunTrialDatalogInput)
  })
_sym_db.RegisterMessage(RunTrialDatalogInput)

RunTrialDatalogOutput = _reflection.GeneratedProtocolMessageType('RunTrialDatalogOutput', (_message.Message,), {
  'DESCRIPTOR' : _RUNTRIALDATALOGOUTPUT,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.RunTrialDatalogOutput)
  })
_sym_db.RegisterMessage(RunTrialDatalogOutput)

SampleInfo = _reflection.GeneratedProtocolMessageType('SampleInfo', (_message.Message,), {
  'DESCRIPTOR' : _SAMPLEINFO,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.SampleInfo)
  })
_sym_db.RegisterMessage(SampleInfo)

DatalogSample = _reflection.GeneratedProtocolMessageType('DatalogSample', (_message.Message,), {
  'DESCRIPTOR' : _DATALOGSAMPLE,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.DatalogSample)
  })
_sym_db.RegisterMessage(DatalogSample)

TrialConfig_v1 = _reflection.GeneratedProtocolMessageType('TrialConfig_v1', (_message.Message,), {
  'DESCRIPTOR' : _TRIALCONFIG_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialConfig_v1)
  })
_sym_db.RegisterMessage(TrialConfig_v1)

ActorConfig_v1 = _reflection.GeneratedProtocolMessageType('ActorConfig_v1', (_message.Message,), {
  'DESCRIPTOR' : _ACTORCONFIG_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.ActorConfig_v1)
  })
_sym_db.RegisterMessage(ActorConfig_v1)

EnvironmentConfig_v1 = _reflection.GeneratedProtocolMessageType('EnvironmentConfig_v1', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTCONFIG_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.EnvironmentConfig_v1)
  })
_sym_db.RegisterMessage(EnvironmentConfig_v1)

EnvironmentParams_v1 = _reflection.GeneratedProtocolMessageType('EnvironmentParams_v1', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTPARAMS_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.EnvironmentParams_v1)
  })
_sym_db.RegisterMessage(EnvironmentParams_v1)

ActorParams_v1 = _reflection.GeneratedProtocolMessageType('ActorParams_v1', (_message.Message,), {
  'DESCRIPTOR' : _ACTORPARAMS_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.ActorParams_v1)
  })
_sym_db.RegisterMessage(ActorParams_v1)

TrialParams_v1 = _reflection.GeneratedProtocolMessageType('TrialParams_v1', (_message.Message,), {
  'DESCRIPTOR' : _TRIALPARAMS_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialParams_v1)
  })
_sym_db.RegisterMessage(TrialParams_v1)

ObservationData_v1 = _reflection.GeneratedProtocolMessageType('ObservationData_v1', (_message.Message,), {
  'DESCRIPTOR' : _OBSERVATIONDATA_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.ObservationData_v1)
  })
_sym_db.RegisterMessage(ObservationData_v1)

ObservationSet_v1 = _reflection.GeneratedProtocolMessageType('ObservationSet_v1', (_message.Message,), {
  'DESCRIPTOR' : _OBSERVATIONSET_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.ObservationSet_v1)
  })
_sym_db.RegisterMessage(ObservationSet_v1)

Action_v1 = _reflection.GeneratedProtocolMessageType('Action_v1', (_message.Message,), {
  'DESCRIPTOR' : _ACTION_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.Action_v1)
  })
_sym_db.RegisterMessage(Action_v1)

RewardSource_v1 = _reflection.GeneratedProtocolMessageType('RewardSource_v1', (_message.Message,), {
  'DESCRIPTOR' : _REWARDSOURCE_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.RewardSource_v1)
  })
_sym_db.RegisterMessage(RewardSource_v1)

Reward_v1 = _reflection.GeneratedProtocolMessageType('Reward_v1', (_message.Message,), {
  'DESCRIPTOR' : _REWARD_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.Reward_v1)
  })
_sym_db.RegisterMessage(Reward_v1)

Message_v1 = _reflection.GeneratedProtocolMessageType('Message_v1', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.Message_v1)
  })
_sym_db.RegisterMessage(Message_v1)

DatalogSample_v1 = _reflection.GeneratedProtocolMessageType('DatalogSample_v1', (_message.Message,), {
  'DESCRIPTOR' : _DATALOGSAMPLE_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.DatalogSample_v1)
  })
_sym_db.RegisterMessage(DatalogSample_v1)

TrialData_v1 = _reflection.GeneratedProtocolMessageType('TrialData_v1', (_message.Message,), {
  'DESCRIPTOR' : _TRIALDATA_V1,
  '__module__' : 'cogment.api.datalog_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialData_v1)
  })
_sym_db.RegisterMessage(TrialData_v1)



_DATALOGSP = _descriptor.ServiceDescriptor(
  name='DatalogSP',
  full_name='cogmentAPI.DatalogSP',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2116,
  serialized_end=2287,
  methods=[
  _descriptor.MethodDescriptor(
    name='RunTrialDatalog',
    full_name='cogmentAPI.DatalogSP.RunTrialDatalog',
    index=0,
    containing_service=None,
    input_type=_RUNTRIALDATALOGINPUT,
    output_type=_RUNTRIALDATALOGOUTPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Version',
    full_name='cogmentAPI.DatalogSP.Version',
    index=1,
    containing_service=None,
    input_type=cogment_dot_api_dot_common__pb2._VERSIONREQUEST,
    output_type=cogment_dot_api_dot_common__pb2._VERSIONINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATALOGSP)

DESCRIPTOR.services_by_name['DatalogSP'] = _DATALOGSP

# @@protoc_insertion_point(module_scope)
